#========================================================================================
# package      DE_EPAGES::MolliePayments::API::Requirement
# state        public
#----------------------------------------------------------------------------------------
# description  Provides methods in order to determine if the requirements 
#               for the usage of MolliePayments are fullfilled.
#========================================================================================
package DE_EPAGES::MolliePayments::API::Requirement;

use DE_EPAGES::MolliePayments::API::Constants qw (
    REQUIRED_BILLING_ADDRESS_FIELDS
);
use strict;

#========================================================================================
# function     new
# state        public
#----------------------------------------------------------------------------------------
# syntax       new( );
#----------------------------------------------------------------------------------------
# description  constructor
#----------------------------------------------------------------------------------------
# input        Shop | Shop object to check the requirements on | 
# return       $self | self | DE_EPAGES::MolliePayments::API::Requirement
#========================================================================================
sub new {
    my $class = shift;
    my ($Shop) = @_;
    my $self  = bless {
        'Shop' => $Shop
    }, $class;
    return $self;
}

#========================================================================================
# function     areMandatoryFieldsSet
# state        public
#----------------------------------------------------------------------------------------
# syntax       $AreMandatoryFieldsSet = $Requirement->areMandatoryFieldsSet();
#----------------------------------------------------------------------------------------
# description  Determines if all necessary billing address fields are set as mandatory.
#----------------------------------------------------------------------------------------
# return       True if all necessary fields are set as mandatory, 
#               otherwise False is returned. | boolean
#========================================================================================
sub areMandatoryFieldsSet {
    my $self = shift;

    foreach my $RequiredFieldName (REQUIRED_BILLING_ADDRESS_FIELDS) {
        if(not $self->_isMandatory($RequiredFieldName)) {
            return 0;
        }
    }
    return 1;
}

#========================================================================================
# function     _isMandatory
# state        private
#----------------------------------------------------------------------------------------
# syntax       _isMandatory( $FieldName );
#----------------------------------------------------------------------------------------
# description  Determines if the field with the passed name is set as mandatory.
#----------------------------------------------------------------------------------------
# input        $FieldName | Name of the field to check | string
# return       True if the field is set as mandatory,
#               otherwise False is returned.            | boolean
#========================================================================================
 sub _isMandatory {
    my $self = shift;
    my ($FieldName) = @_;

    my $Shop = $self->{'Shop'};
    my $MandatoryBillingAddressFields = $Shop->get('BillingAddressSetMandatoryFields');
    my $IsMandatory = $MandatoryBillingAddressFields =~ /$FieldName/;

    return $IsMandatory;
 }

1;