#========================================================================================
# package      DE_EPAGES::PayPalExpress::Hooks::Servlet
# state        public
# description  Additional hook function for OnIsEp6HandledUnityRequest hook.
#========================================================================================
package DE_EPAGES::PayPalExpress::Hooks::Servlet;

use strict;

#========================================================================================
# function     OnIsEp6HandledUnityRequest
# state        public
#----------------------------------------------------------------------------------------
# syntax       OnIsEp6HandledUnityRequest($hParams);
#----------------------------------------------------------------------------------------
# description  Triggered by hook IsEp6HandledUnityRequest.
#               The checkout process should be rendered by epages6 for any Unity shop.
#----------------------------------------------------------------------------------------
# input        $hParams | hook arguments, used keys are
#               <ul>
#                   <li>Object - servlet object</li>
#                   <li>Values - attributes</li>
#               </ul> | ref.hash.*
#========================================================================================
sub OnIsEp6HandledUnityRequest {
    my ($hParams) = @_;
    my $Servlet = $hParams->{'Object'};

    # skip if another hook function already acknowledges the request as a unity request handled by epages6
    return if $hParams->{'Values'}->{'IsEp6HandledUnityRequest'};

    my @ChangeActions = $Servlet->form->value('ChangeAction');
    my @ChangeActionsHandledByEpages6 = (
      'PayPalExpressIPN',
      'PayPalExpressGiroPaySuccess',
      'PayPalExpressGiroPayCancel',
      'Refund',
      'PayPalExpress',
      'PayPalExpressCallback',
    );

    foreach my $ChangeActionHandledByEpages6 (@ChangeActionsHandledByEpages6){
        if (scalar @ChangeActions and $ChangeActionHandledByEpages6 ~~ @ChangeActions) {
            $hParams->{'Values'}->{'IsEp6HandledUnityRequest'} = 1;
            return;
        }
    }

    my $aViewActionsHandledByEp6 = [
        'ViewPayPalExpressCancel', 'UnityViewSFPayPalExpressFailed'
    ];

    my $aChangeActionsHandledByEp6 = [
       'PayPalExpressReturn' , 'PayPalExpressCancel'
    ];

    my $ViewAction = $Servlet->params('ViewAction');
    my $ChangeAction = $Servlet->params('ChangeAction') // '';

    if($ViewAction ~~ $aViewActionsHandledByEp6 || $ChangeAction ~~ $aChangeActionsHandledByEp6) {
        $hParams->{'Values'}->{'IsEp6HandledUnityRequest'} = 1;
    }
    return;
}

1;