#========================================================================================
# package      DE_EPAGES::PriceList::API::Table::PriceListCustomerGroup
# state        public
# description  interface for table PriceListCustomerGroup
#========================================================================================
package DE_EPAGES::PriceList::API::Table::PriceListCustomerGroup;
use base qw( Exporter );

use strict;
our @EXPORT_OK = qw(
    InsertPriceListCustomerGroup
    DeletePriceListCustomerGroup
    GetAllPKeyPriceListCustomerGroups
    ExistsPriceListCustomerGroup
    GetPKeyPriceListCustomerGroupsByPriceListID
    GetInfoPriceListCustomerGroupsByPriceListID
    GetPKeyPriceListCustomerGroupsByCustomerGroupID
    GetInfoPriceListCustomerGroupsByCustomerGroupID
);

use DE_EPAGES::Core::API::TestParameter qw ( TestString TestInteger TestFloat TestDateTime ); ## no critic qw(RequireCorrectImports)
use DE_EPAGES::Trigger::API::Trigger    qw ( TriggerHook );
use DE_EPAGES::PriceList::DAL::PriceList;

#ERRORDEFINITION
sub ErrorDefinition {
    return {
        'NoResults_PriceListCustomerGroup' => 'PriceListCustomerGroup doesn\'t exist (PriceListID=#PriceListID, CustomerGroupID=#CustomerGroupID)',
    };
}
#ERRORDEFINITION END

#========================================================================================
# function     InsertPriceListCustomerGroup
#----------------------------------------------------------------------------------------
# syntax       InsertPriceListCustomerGroup($hPriceListCustomerGroup);
#----------------------------------------------------------------------------------------
# description  Creates an entry of PriceListCustomerGroup.
#----------------------------------------------------------------------------------------
# input        $hPriceListCustomerGroup | with following keys:
#               <ul>
#                   <li>PriceListID   - price list id        (part of primary key)- int
#                   <li>CustomerGroupID - customer group id    (part of primary key)- int
#               </ul> | reference to hash
#========================================================================================
sub InsertPriceListCustomerGroup ($) {
    my ($hPriceListCustomerGroup) = @_;
    DAL_InsertPriceListCustomerGroup($hPriceListCustomerGroup);
    my $PriceListID = $hPriceListCustomerGroup->{'PriceListID'};
    my $CustomerGroupID = $hPriceListCustomerGroup->{'CustomerGroupID'};
    TriggerHook('API_InsertPriceListCustomerGroup', { 'PriceListID' => $PriceListID, 'CustomerGroupID' => $CustomerGroupID });
    return;
}

#========================================================================================
# function     DeletePriceListCustomerGroup
#----------------------------------------------------------------------------------------
# syntax       DeletePriceListCustomerGroup($PriceListID, $CustomerGroupID);
# syntax       DeletePriceListCustomerGroup($hPriceListCustomerGroup); # if $hPriceListCustomerGroup includes PriceListID, CustomerGroupID
#----------------------------------------------------------------------------------------
# description  Deletes a(n) PriceListCustomerGroup.
#----------------------------------------------------------------------------------------
# input        $PriceListID   | price list id        (part of primary key) | int
# input        $CustomerGroupID | customer group id    (part of primary key) | int
#========================================================================================
sub DeletePriceListCustomerGroup ($;$) {
    my ($PriceListID, $CustomerGroupID) = @_;
    if (ref $PriceListID eq 'HASH') {
        my $hInfo = $PriceListID;
        $PriceListID = $hInfo->{'PriceListID'};
        $CustomerGroupID = $hInfo->{'CustomerGroupID'};
    }
    TestInteger('PriceListID',$PriceListID);
    TestInteger('CustomerGroupID',$CustomerGroupID);
    TriggerHook('API_DeletePriceListCustomerGroup', { 'PriceListID' => $PriceListID, 'CustomerGroupID' => $CustomerGroupID } );
    DAL_DeletePriceListCustomerGroup($PriceListID, $CustomerGroupID);
    return;
}

#========================================================================================
# function     GetAllPKeyPriceListCustomerGroups
#----------------------------------------------------------------------------------------
# syntax       $ahPriceListCustomerGroupIDs = GetAllPKeyPriceListCustomerGroups();
#----------------------------------------------------------------------------------------
# description  Returns all PriceListCustomerGroup identifiers.
#----------------------------------------------------------------------------------------
# return       $ahPriceListCustomerGroupIDs | with following keys:
#               <ul>
#                   <li>PriceListID   - price list id        (part of primary key)- int
#                   <li>CustomerGroupID - customer group id    (part of primary key)- int
#               </ul>| reference to array of hashes
#========================================================================================
sub GetAllPKeyPriceListCustomerGroups () { DAL_GetAllPKeyPriceListCustomerGroups(); }

#========================================================================================
# function     ExistsPriceListCustomerGroup
#----------------------------------------------------------------------------------------
# syntax       $exists = ExistsPriceListCustomerGroup($PriceListID, $CustomerGroupID);
#----------------------------------------------------------------------------------------
# description  Returns true if the PriceListCustomerGroup exists.
#----------------------------------------------------------------------------------------
# input        $PriceListID   | price list id        (part of primary key) | int
# input        $CustomerGroupID | customer group id    (part of primary key) | int
# return       $exists | 1/0  the PriceListCustomerGroup exists (yes/no) | boolean
#========================================================================================
sub ExistsPriceListCustomerGroup ($$) {
    my ($PriceListID, $CustomerGroupID) = @_;
    TestInteger('PriceListID',$PriceListID);
    TestInteger('CustomerGroupID',$CustomerGroupID);
    my $hPriceListCustomerGroup = DAL_GetInfoPriceListCustomerGroup($PriceListID, $CustomerGroupID);
    return defined $hPriceListCustomerGroup ? 1 : 0;
}

#========================================================================================
# function     GetPKeyPriceListCustomerGroupsByPriceListID
#----------------------------------------------------------------------------------------
# syntax       $ahKeys = GetPKeyPriceListCustomerGroupsByPriceListID($PriceListID);
#----------------------------------------------------------------------------------------
# description  Returns primary keys of PriceListCustomerGroup by primary key element PriceListID.
#----------------------------------------------------------------------------------------
# input        $PriceListID | price list id | int
# return       $ahKeys | with following keys:
#               <ul>
#                   <li>PriceListID   - price list id        (part of primary key)- int
#                   <li>CustomerGroupID - customer group id    (part of primary key)- int
#               </ul> | reference to array of hashes
#========================================================================================
sub GetPKeyPriceListCustomerGroupsByPriceListID ($) {
    my ($PriceListID) = @_;
    TestInteger('PriceListID',$PriceListID);
    return DAL_GetPKeyPriceListCustomerGroupsByPriceListID($PriceListID);
}

#========================================================================================
# function     GetInfoPriceListCustomerGroupsByPriceListID
#----------------------------------------------------------------------------------------
# syntax       $ahPriceListCustomerGroups = GetInfoPriceListCustomerGroupsByPriceListID($PriceListID);
#----------------------------------------------------------------------------------------
# description  Returns objects of PriceListCustomerGroup by primary key element PriceListID.
#----------------------------------------------------------------------------------------
# input        $PriceListID | price list id | int
# return       $ahPriceListCustomerGroups | with following keys:
#               <ul>
#                   <li>PriceListID   - price list id        (part of primary key)- int
#                   <li>CustomerGroupID - customer group id    (part of primary key)- int
#               </ul> | reference to array of hashes
#========================================================================================
sub GetInfoPriceListCustomerGroupsByPriceListID ($) {
    my ($PriceListID) = @_;
    TestInteger('PriceListID',$PriceListID);
    return DAL_GetInfoPriceListCustomerGroupsByPriceListID($PriceListID);
}

#========================================================================================
# function     GetPKeyPriceListCustomerGroupsByCustomerGroupID
#----------------------------------------------------------------------------------------
# syntax       $ahKeys = GetPKeyPriceListCustomerGroupsByCustomerGroupID($CustomerGroupID);
#----------------------------------------------------------------------------------------
# description  Returns primary keys of PriceListCustomerGroup by alternate key CustomerGroupID.
#----------------------------------------------------------------------------------------
# input        $CustomerGroupID | customer group id | int
# return       $ahKeys | with following keys:
#               <ul>
#                   <li>PriceListID   - price list id        (part of primary key)- int
#                   <li>CustomerGroupID - customer group id    (part of primary key)- int
#               </ul> | reference to array of hashes
#========================================================================================
sub GetPKeyPriceListCustomerGroupsByCustomerGroupID ($) {
    my ($CustomerGroupID) = @_;
    TestInteger('CustomerGroupID',$CustomerGroupID);
    return DAL_GetPKeyPriceListCustomerGroupsByCustomerGroupID($CustomerGroupID);
}

#========================================================================================
# function     GetInfoPriceListCustomerGroupsByCustomerGroupID
#----------------------------------------------------------------------------------------
# syntax       $ahPriceListCustomerGroups = GetInfoPriceListCustomerGroupsByCustomerGroupID($CustomerGroupID);
#----------------------------------------------------------------------------------------
# description  Returns objects of PriceListCustomerGroup by alternate key CustomerGroupID.
#----------------------------------------------------------------------------------------
# input        $CustomerGroupID | customer group id | int
# return       $ahPriceListCustomerGroups | with following keys:
#               <ul>
#                   <li>PriceListID   - price list id        (part of primary key)- int
#                   <li>CustomerGroupID - customer group id    (part of primary key)- int
#               </ul> | reference to array of hashes
#========================================================================================
sub GetInfoPriceListCustomerGroupsByCustomerGroupID ($) {
    my ($CustomerGroupID) = @_;
    TestInteger('CustomerGroupID',$CustomerGroupID);
    return DAL_GetInfoPriceListCustomerGroupsByCustomerGroupID($CustomerGroupID);
}

#========================================================================================
# function     OnDeleteCustomerGroup
#----------------------------------------------------------------------------------------
# syntax       OnDeleteCustomerGroup($hParams);
#----------------------------------------------------------------------------------------
# description  Deletes PriceListCustomerGroup of this model when a(n) CustomerGroup is deleted.
#----------------------------------------------------------------------------------------
# input        $hParams | primary key of object CustomerGroup, key is
#               <ul>
#                   <li>Object        - this object          - object
#                   <li>CustomerGroupID
#               </ul> | ref.hash.*
#========================================================================================
sub OnDeleteCustomerGroup {
    my ($hParams) = @_;

    #do nothing if we have a unity shop
    return if $hParams->{'Object'}->getSite()->get('IsUnityRegistered');

    DeletePriceListCustomerGroup($_) foreach @{GetPKeyPriceListCustomerGroupsByCustomerGroupID($hParams->{'CustomerGroupID'})};

}

1;

