#========================================================================================
# package      DE_EPAGES::PriceList::Hooks::CustomerGroup
# state        public
# description  insert and deletes pricelists for customergroups
#========================================================================================
package DE_EPAGES::PriceList::Hooks::CustomerGroup;

use DE_EPAGES::Object::API::Factory qw( LoadClassByAlias );

use strict;

#========================================================================================
# function     OnInsertCustomerGroup
#----------------------------------------------------------------------------------------
# syntax       OnInsertCustomerGroup( $hParams );
#----------------------------------------------------------------------------------------
# description  Creates a new unity pricelist for given customergroup
#               Triggered by OBJ_InsertCustomerGroup
#----------------------------------------------------------------------------------------
# input        $hParams |
#               ul>
#                 <li>Object        - this object          - object
#                 <li>CustomerGroupID - customergroup id   - int
#               </ul>
#========================================================================================
sub OnInsertCustomerGroup {
    my ($hParams) = @_;

    # run this only for not simplified customer group NewCustomer and Unity shops
    return if $hParams->{'Object'}->alias eq 'NewCustomer';
    my $Shop = $hParams->{'Object'}->getSite();
    return unless $Shop->get('IsUnityRegistered');
    my $CustomerGroup = $hParams->{'Object'};

    my $Folder = $Shop->folder('PriceLists', { 'Position' => 30 });
    my $PriceListAlias = $hParams->{'Object'}->alias;

    my $Class = LoadClassByAlias('PriceList');
    my $hPriceList = {
        'Parent'     => $Folder,
        'Alias'      => $PriceListAlias,
        'ValidFrom'  => DateTime->now(),
        'ValidTo'    => DateTime->new('year' => 2999, 'month' => 1, 'day' => 1),
        'CurrencyID' => $Shop->get('CurrencyID'),
    };
    my $PriceList = $Class->insertObject($hPriceList);

    # assign unity customergroup to pricelist
    $PriceList->addCustomerGroup($CustomerGroup);

    return;
}

#========================================================================================
# function     OnDeleteCustomerGroupUnity
#----------------------------------------------------------------------------------------
# syntax       OnDeleteCustomerGroupUnity( $hParams );
#----------------------------------------------------------------------------------------
# description  Deletes unity priceslist assigned to given customergroup.
#               Triggered by OBJ_DeleteCustomerGroup
#----------------------------------------------------------------------------------------
# input        $hParams |
#               ul>
#                 <li>Object        - this object          - object
#                 <li>CustomerGroupID - customergroup id   - int
#               </ul>
#========================================================================================
sub OnDeleteCustomerGroupUnity {
    my ($hParams) = @_;
    my $hCustomerGroup = $hParams->{'Object'};
    my $Shop = $hParams->{'Object'}->getSite();
    return unless $Shop->get('IsUnityRegistered');

    my @PriceLists = @{$hCustomerGroup->get('PriceLists')};
    foreach my $PriceList (@PriceLists){
        $PriceList->delete;;
    }
    return;
}
1;

