#========================================================================================
# package      DE_EPAGES::ShopMigration::API::WebService::MigrationShopService;
# state        public
#----------------------------------------------------------------------------------------
# description  Provides a service to get all shops with MigrationStatus
#                 SHOPMIGRATION_FINAL_SHOPTYPECHANGE_ALLOW
#========================================================================================
package DE_EPAGES::ShopMigration::API::WebService::MigrationShopService;
use base DE_EPAGES::WebService::API::WebService::BaseService;

use strict;
use DE_EPAGES::Core::API::Log qw (LogDebug);
use DE_EPAGES::ShopMigration::API::Constants qw (SHOPMIGRATION_FINAL_SHOPTYPECHANGE_ALLOW);
use DE_EPAGES::ShopMigration::API::MigrationShop qw (FindAllShopsWithMigrationStatus);

#========================================================================================
# function     getShopsWithShopTypeChangeAllow
# state        public
#----------------------------------------------------------------------------------------
# syntax       my $aShopIDs = $MigrationShopService->getShopsWithShopTypeChangeAllow->result;
#----------------------------------------------------------------------------------------
# description  Returns a list of all shops with MigrationStatus=SHOPMIGRATION_FINAL_SHOPTYPECHANGE_ALLOW
#----------------------------------------------------------------------------------------
# return       $aShopIDs | array of shopids  | ref.array.integer
#========================================================================================
sub getShopsWithShopTypeChangeAllow {
    shift;
    my $aShops = FindAllShopsWithMigrationStatus(SHOPMIGRATION_FINAL_SHOPTYPECHANGE_ALLOW);
    my $aShopIDs = [map { $_->id } @{$aShops}];
    LogDebug('aShopIDs=', $aShopIDs);
    return $aShopIDs;
}

1;
