#========================================================================================
# package      DE_EPAGES::ShopMigration::UI::JSON
# state        public
#----------------------------------------------------------------------------------------
# description  Common user interface to show migration dialog
#========================================================================================
package DE_EPAGES::ShopMigration::UI::JSON;
use base DE_EPAGES::Presentation::UI::JSON;

use strict;
use DE_EPAGES::Database::API::Connection qw ( GetCurrentDBHandle );
use DE_EPAGES::ShopMigration::API::Constants qw( SHOPMIGRATION_INITIAL_IN_PROGRESS );
use DE_EPAGES::XML::API::SOAPDateTimeFormatXML;
use JSON;


#========================================================================================
# function     JSONMigrationDialog
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Handler->JSONMigrationDialog( $Servlet );
#----------------------------------------------------------------------------------------
# description  save parameters from the migration dialog
#----------------------------------------------------------------------------------------
# input        $Servlet | current servlet (contains form data) | object
# return       $ReturnValue | a html template | String
#========================================================================================
sub JSONMigrationDialog {
    my $self = shift;
    my ($Servlet) = @_;
    my $Shop = $Servlet->object;

    my $hParams = {};

    # get already written parameters from the attribute MigrationDialogParameters
    my $JSONDialogParameters = $Shop->get('MigrationDialogParameters');

    # get or set flag for PrepShop dialog
    $hParams->{'PrepShopDialogSeen'} = (not defined $JSONDialogParameters) ? 0 : ((decode_json($JSONDialogParameters))->{'PrepShopDialogSeen'} || 0);

    # get values from dialog
    $hParams->{'IsNotInterested'}   = $Servlet->form->value('IsNotInterested') eq 'false' ? 0 : 1;
    $hParams->{'DialogCount'}       = $Servlet->form->value('DialogCount');

    # increase DialogCount
    $hParams->{'DialogCount'} ++;

    # change IsNotInterested,  DialogCount++ , change DialogCloseDate and save
    my $Parser = DE_EPAGES::XML::API::SOAPDateTimeFormatXML->new();
    my $DateTimeString = $Parser->format_datetime(GetCurrentDBHandle()->currentDateTime);
    $hParams->{'DialogCloseDate'} = $DateTimeString;

    # convert to JSON and save to data base
    my $JSONValues = to_json($hParams);
    $Shop->set({'MigrationDialogParameters' => $JSONValues });

    my $hJSONResponse = {
        'success' => JSON::true,
    };

    return $self->writeContentOutput($hJSONResponse);
}

#========================================================================================
# function     JSONPrepShopReadyDialog
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Handler->JSONPrepShopReadyDialog( $Servlet );
#----------------------------------------------------------------------------------------
# description  save flag to handle state of PrepShop dialog
#----------------------------------------------------------------------------------------
# input        $Servlet | current servlet (contains form data) | object
# return       $ReturnValue | a html template | String
#========================================================================================
sub JSONPrepShopReadyDialog {
    my $self = shift;
    my ($Servlet) = @_;
    my $Shop = $Servlet->object;

    my $PrepShopDialogSeen = $Servlet->form->value('PrepShopDialogSeen') eq 'false' ? 0 : 1;

    # get already written parameters from the attribute MigrationDialogParameters
    my $JSONDialogParameters = $Shop->get('MigrationDialogParameters');

    # extract parameters
    my $hDialogParameters = decode_json($JSONDialogParameters);
    # set PrepShopDialog flag
    $hDialogParameters->{'PrepShopDialogSeen'} = $PrepShopDialogSeen;

    # save JSON string to data base
    $JSONDialogParameters = to_json($hDialogParameters);
    $Shop->set({'MigrationDialogParameters' => $JSONDialogParameters});

    my $hJSONResponse = {
        'success' => JSON::true,
    };

    return $self->writeContentOutput($hJSONResponse);
}

#========================================================================================
# function     JSONCreatePrepShop
# state        private
#----------------------------------------------------------------------------------------
# syntax       $Handler->JSONCreatePrepShop( $Servlet );
#----------------------------------------------------------------------------------------
# description  initiate the creation of a PrepShop
#----------------------------------------------------------------------------------------
# input        $Servlet | current servlet (contains form data) | object
# return       $ReturnValue | a html template | String
#========================================================================================
sub JSONCreatePrepShop {
    my $self = shift;
    my ($Servlet) = @_;
    my $Shop = $Servlet->object;

    # set flag that prep shop should be created
    $Shop->set({'MigrationStatus' => SHOPMIGRATION_INITIAL_IN_PROGRESS});

    my $hJSONResponse = {
        'success' => JSON::true,
    };

    return $self->writeContentOutput($hJSONResponse);
}

1;
