#=====================================================================================================================#
# package      DE_EPAGES::ShopMigrationProvider::API::Constants
# state        public
# description  Constants of cartridge ShopMigrationProvider
#=====================================================================================================================#
package DE_EPAGES::ShopMigrationProvider::API::Constants;
use base Exporter;

use strict;
our @EXPORT_OK = qw(
    SHOPMIGRATION_NOT_PARTICIPATING
    SHOPMIGRATION_INITIAL_ALLOW
    SHOPMIGRATION_INITIAL_IN_PROGRESS
    SHOPMIGRATION_INITAL_PREPARED
    SHOPMIGRATION_INITAL_FAILED
    SHOPMIGRATION_FINAL_ALLOW
    SHOPMIGRATION_FINAL_IN_PROGRESS
    SHOPMIGRATION_FINAL_SHOPTYPECHANGE_ALLOW
    SHOPMIGRATION_FINAL_DONE
    SHOPMIGRATION_FINAL_FAILED
    %SHOPMIGRATION_SHOPTYPE_MAPPING
);

use DE_EPAGES::ShopMigrationProvider::API::ShopMigrationConfig qw( GetShopTypeMapping);

#=====================================================================================================================#
# global   SHOPMIGRATION_NOT_PARTICIPATING | (default) shop is not migratable or was not
#               yet checked for migratable status | integer
# global   SHOPMIGRATION_INITIAL_ALLOW | shop is migratable/show migrate button in MBO
# global   SHOPMIGRATION_INITIAL_IN_PROGRESS | initial migration is in progress/disable migrate button in MBO
# global   SHOPMIGRATION_INITAL_PREPARED | initial migration is done/show login button in MBO
# global   SHOPMIGRATION_INITAL_FAILED | initial migration failed due to some error
#              (e.g. NowShop could not be created or data import errors)
# global   SHOPMIGRATION_FINAL_ALLOW | allow final migration step/show button in MBO
# global   SHOPMIGRATION_FINAL_IN_PROGRESS | final migration is in progress
# global   SHOPMIGRATION_FINAL_SHOPTYPECHANGE_ALLOW | final migration is done but shoptype needs to be changed by Site
# global   SHOPMIGRATION_FINAL_DONE | final migration is done for this shop
# global   SHOPMIGRATION_FINAL_FAILED | final migration step failed
#========================================================================================
use constant SHOPMIGRATION_NOT_PARTICIPATING => 0;
use constant SHOPMIGRATION_INITIAL_ALLOW => 1;
use constant SHOPMIGRATION_INITIAL_IN_PROGRESS => 2;
use constant SHOPMIGRATION_INITAL_PREPARED => 4;
use constant SHOPMIGRATION_INITAL_FAILED => 8;
use constant SHOPMIGRATION_FINAL_ALLOW => 16;
use constant SHOPMIGRATION_FINAL_IN_PROGRESS => 32;
use constant SHOPMIGRATION_FINAL_SHOPTYPECHANGE_ALLOW => 64;
use constant SHOPMIGRATION_FINAL_DONE => 128;
use constant SHOPMIGRATION_FINAL_FAILED => 256;

#=====================================================================================================================#
# global  %SHOPMIGRATION_SHOPTYPE_MAPPING | mapping for releated shoptypes (base -> now)
#=====================================================================================================================#
our %SHOPMIGRATION_SHOPTYPE_MAPPING = %{GetShopTypeMapping()};

1;

