#========================================================================================
# package      DE_EPAGES::ShopMigrationProvider::API::ShopMigrationConfig
# state        public
# description  Interface to the shopmigration.conf file.
#               This configuration file is case sensitive.
#========================================================================================
package DE_EPAGES::ShopMigrationProvider::API::ShopMigrationConfig;
use base qw(Exporter);
use strict;

our @EXPORT_OK = qw(
    ShopMigrationConfig
    GetShopTypeMapping
);

use DE_EPAGES::Core::API::File qw(GetCachedFile);
use DE_EPAGES::Core::API::IniConfig;

my $CONFIG_FILENAME = "$ENV{'EPAGES_CONFIG'}/shopmigration.conf";

#========================================================================================
# function     ShopMigrationConfig
# state        public
#----------------------------------------------------------------------------------------
# syntax       $IniConfig = ShopMigrationConfig();
# example      my $Value = ShopMigrationConfig->get('section', 'key', $defaultvalue);
#----------------------------------------------------------------------------------------
# description  Returns an  IniConfig object of the shopmigration.conf file.
#               see <package DE_EPAGES::Core::API::IniConfig>
#----------------------------------------------------------------------------------------
# return       $IniConfig | config object | object
#========================================================================================
sub ShopMigrationConfig() {
    return GetCachedFile($CONFIG_FILENAME, sub {
        my ($FileName) = @_;
        return DE_EPAGES::Core::API::IniConfig->new(
            FileName      => $FileName,
            Create        => 1,
            CaseSensitive => 1,
        );
    });
}

#========================================================================================
# function     GetShopTypeMapping
#----------------------------------------------------------------------------------------
# syntax       $hShopTypeMapping = GetShopTypeMapping();
#----------------------------------------------------------------------------------------
# description  Returns shoptype mapping from shopmigration.conf
#               section ShopMigrationPrepShop.ShopTypeMapping
#----------------------------------------------------------------------------------------
# return       $hShopTypeMapping | hash with shoptype alias mapping
#                   key: base shoptype, value: related now shoptype  | reference to hash
#========================================================================================
sub GetShopTypeMapping() {
    return ShopMigrationConfig()->section('ShopMigrationPrepShop.ShopTypeMapping');
}

1;
