#========================================================================================
# §nocomments
# §package      DE_EPAGES::Spreedly::API::Constants
# §state        private
#----------------------------------------------------------------------------------------
# §description  constants for cartridge
#========================================================================================
package DE_EPAGES::Spreedly::API::Constants;
use base Exporter;

use strict;

our @EXPORT_OK = qw (
    INTERNAL_CARTRIDGE_NAME
    IS_PAYMENT_METHOD_OK
    IS_PAYMENT_METHOD_NOK
    CREDIT_CARD
    OPERATIONAL_MODE_LIVE
    OPERATIONAL_MODE_TEST
    PURCHASE_REQUEST_THREE_DS_VERSION
    PURCHASE_REQUEST_ATTEMPT_3DSECURE
    PURCHASE_RESPONSE_STATE_SUCEEDED
    PURCHASE_RESPONSE_STATE_PENDING
    PURCHASE_RESPONSE_STATE_PROCESSING
    PURCHASE_RESPONSE_REQUIRED_ACTION_REDIRECT
    THREE_DS_AVAILABLE_GATEWAYS
    SPECIFIC_FIELDS_GATEWAYS
    SPREEDLY_GATEWAY_NAME_PAYU_LATAM
    PAYMENT_STATUS_PAID
    PAYMENT_STATUS_FAILED
    PAYMENT_STATUS_PROCESSING
    FAILURE_MESSAGES
    JSON_FAILURE_MESSAGES
    PAYMENT_TYPE_ALIAS_SPREEDLY_TEST
    @PAYMENT_TYPE_NAMES
    %STRIPE_DEFAULTS
    %STRIPE_PAYMENT_INTENTS_DEFAULTS
    %AUTHORIZE_DEFAULTS
    %EVO_DEFAULTS
    %MERCADOPAGO_DEFAULTS
    %PAYEEZY_DEFAULTS
    %PAYULATAM_DEFAULTS
    %PAYMENTEZ_DEFAULTS
);



# This name is used to load objects from database (DON'T CHANGE!)
use constant INTERNAL_CARTRIDGE_NAME => 'Spreedly';
use constant CREDIT_CARD => 'credit_card';
use constant IS_PAYMENT_METHOD_OK => 1;
use constant IS_PAYMENT_METHOD_NOK => 0;
use constant OPERATIONAL_MODE_LIVE => 'live';
use constant OPERATIONAL_MODE_TEST => 'test';
use constant PURCHASE_REQUEST_THREE_DS_VERSION => '2';
use constant PURCHASE_REQUEST_ATTEMPT_3DSECURE => 'true';
use constant PURCHASE_RESPONSE_STATE_SUCEEDED => 'succeeded';
use constant PURCHASE_RESPONSE_STATE_PENDING => 'pending';
use constant PURCHASE_RESPONSE_STATE_PROCESSING => 'processing';
use constant PURCHASE_RESPONSE_REQUIRED_ACTION_REDIRECT => 'redirect';
use constant PAYMENT_STATUS_PAID => 'STATUS_PAID';
use constant PAYMENT_STATUS_FAILED => 'STATUS_FAILED';
use constant PAYMENT_STATUS_PROCESSING => 'STATUS_PROCESSING';

use constant FAILURE_MESSAGES => {
    'Name' => {
        'Purchase' => 'SpreedlyMakePurchaseError',
        'MobilePurchase' => 'SpreedlyMobileMakePurchaseError',
        'Complete' => 'SpreedlyCompleteTransactionError',
    },
    'Reason' => {
        'CardDeclined' => 'card_declined',
        'UnknownError' => 'unknown_error_code',
        'ConnectionError' => 'ConnectionError',
    }
};

# This JSON_FAILURE_MESSAGES have to match with the Key of FAILURE_MESSAGES
use constant JSON_FAILURE_MESSAGES => {
    'Name' => {
        'Purchase' => 'Purchase',
        'MobilePurchase' => 'MobilePurchase',
        'Complete' => 'Complete',
    },
    'Reason' => {
        'CardDeclined' => 'CardDeclined',
        'UnknownError' => 'UnknownError',
        'ConnectionError' => 'ConnectionError',
    }
};

our @PAYMENT_TYPE_NAMES = (
    qw (
        SpreedlyTest
        SpreedlyStripe
        SpreedlyStripePaymentIntents
        SpreedlyAuthorize
        SpreedlyAuthorizeEvo
        SpreedlyMercadoPago
        SpreedlyPayULatam
        SpreedlyPayeezy
        SpreedlyPaymentez
    )
);

use constant PAYMENT_TYPE_ALIAS_SPREEDLY_TEST => 'SpreedlyTest';

use constant THREE_DS_AVAILABLE_GATEWAYS => [qw( test stripe_payment_intents )];
use constant SPECIFIC_FIELDS_GATEWAYS => [qw( payu_latam stripe_payment_intents )];
use constant SPREEDLY_GATEWAY_NAME_PAYU_LATAM => 'payu_latam';

our %STRIPE_DEFAULTS = (
    'PaymentTypeMethod_Object_Path' => '/PaymentTypes/SpreedlyStripe/PaymentTypeMethods/CreditCard/DebitCreditCard',
);

our %STRIPE_PAYMENT_INTENTS_DEFAULTS = (
    'PaymentTypeMethod_Object_Path' => '/PaymentTypes/SpreedlyStripePaymentIntents/PaymentTypeMethods/CreditCard/DebitCreditCard',
);

our %AUTHORIZE_DEFAULTS = (
    'PaymentTypeMethod_Object_Path' => '/PaymentTypes/SpreedlyAuthorize/PaymentTypeMethods/CreditCard/DebitCreditCard',
);

our %EVO_DEFAULTS = (
    'PaymentTypeMethod_Object_Path' => '/PaymentTypes/SpreedlyAuthorizeEvo/PaymentTypeMethods/CreditCard/DebitCreditCard',
);

our %MERCADOPAGO_DEFAULTS = (
    'PaymentTypeMethod_Object_Path' => '/PaymentTypes/SpreedlyMercadoPago/PaymentTypeMethods/CreditCard/DebitCreditCard',
);

our %PAYULATAM_DEFAULTS = (
    'PaymentTypeMethod_Object_Path' => '/PaymentTypes/SpreedlyPayULatam/PaymentTypeMethods/CreditCard/DebitCreditCard',
);

our %PAYEEZY_DEFAULTS = (
    'PaymentTypeMethod_Object_Path' => '/PaymentTypes/SpreedlyPayeezy/PaymentTypeMethods/CreditCard/DebitCreditCard',
);

our %PAYMENTEZ_DEFAULTS = (
    'PaymentTypeMethod_Object_Path' => '/PaymentTypes/SpreedlyPaymentez/PaymentTypeMethods/CreditCard/DebitCreditCard',
);

1;
